PROGRAM PL513TST;

{=====================================================================}
{ PURPOSE :                                                           }
{                                                                     }
{=====================================================================}
{ SYSTEM  : MS-DOS / Turbo Pascal                                     }
{                      Ver. 7.0                                       }
{ Author: Mike Genovy                                                 }
{ Date :  Nov 3, 2000                                                 }
{ Date :  Oct 2, 1999 - Original code                                 }
{                                                                     }
{ Comments:                                                           }
{ ---------                                                           }
{           This program is a demo of how to call Control.exe in a    }
{ Pascal program.                                                     }
{                                                                     }
{=====================================================================}

{ $M 1024,0,0 }

USES Dos,Crt;

CONST

   Title    = 'PL513 - Pascal program to call Control.exe with command line parameters';
   Version  = 'Version 1.00';

VAR
   ChIn : Char;
   HouseStr       : string;   { House Number  }
   ModuleStr      : string;   { Module Number }
   FunctionStr    : string;   { Function Code }
   RepeatStr      : string;   { Repeat Factor }
   CommandLineStr : string;   { Command Line string passed to Control }

{=====================================================================}
{  Display menu selections                                            }
{=====================================================================}

PROCEDURE DisplayMenu;

BEGIN

  WriteLn ('+------------------------------------------------------+');
  WriteLn('| Please enter a command....                           | ');
  WriteLn ('+------------------------------------------------------+');
  WriteLn;
  WriteLn(' 1 = Turn  on Module 1 ( House A ) ');
  WriteLn(' 2 = Turn off Module 1 ( House A ) ');
  WriteLn(' 3 = Turn  on Module 2 ( House A ) ');
  WriteLn(' 4 = Turn off Module 2 ( House A ) ');
  WriteLn;
  WriteLn(' I or i = Enter Interactive mode ');
  WriteLn;
  WriteLn(' Push ESC or Control C to abort ');

END; { DisplayMenu }

{=====================================================================}
{  TestPL513 - Routine to test Control.exe command line parameters    }
{=====================================================================}

PROCEDURE TestPL513;

{----------------------------------------------------------------------}
{ Control can be used in a non-TSR mode to send one command via        }
{ command line parameters. The PL513 can be connected to the dedicated }
{ Gencor parallel card or the highest LPT card installed. If the PL513 }
{ is connected to the Gencor parallel card a /h must be specified on   }
{ the command line. For the PL513 connected to the highest LPT card    }
{ installed only the /s parameter is needed. The command lines must    }
{ be entered as shown below.                                           }
{                                                                      }
{   For Dedicated Gencor Parallel Card:                                }
{   -----------------------------------                                }
{                                                                      }
{   control /h /s(house,module,function,repeat)                        }
{                                                                      }
{   For Highest Installed LPT card:                                    }
{   ------------------------------                                     }
{                                                                      }
{   control /s(house,module,function,repeat)                           }
{                                                                      }
{                                                                      }
{   Where:    house     = 1 to 3                                       }
{                                                                      }
{             module    = 1 to 16                                      }
{                                                                      }
{             function  = AUF AUN ALN ALF AAN AAF ON OFF DIM BRT       }
{                                                                      }
{             repeat    = 1 to 10                                      }
{                         ( only needed if function is DIM or BRT )    }
{                                                                      }
{   Function Code Meaning:                                             }
{   ----------------------                                             }
{                                                                      }
{   AUF = All units off                                                }
{   AUN = All units on                                                 }
{   ALN = All lamps on                                                 }
{   ALF = All lamps off                                                }
{   AAN = All appliances on                                            }
{   AAF = All appliances off                                           }
{   ON  = Single module on                                             }
{   OFF = Single module off                                            }
{   DIM = Lamp module dim                                              }
{   BRT = lamp module bright                                           }
{                                                                      }
{----------------------------------------------------------------------}

CONST

   Tab   = ^I;  { ASCII tab character   }
   Null  = #00; { ASCII Null character  }
   DC4   = #20; { ASCII DC4 character   }
   RS    = #30; { ASCII RS character    }
   Blank = #32; { ASCII Blank Character }
   CR    = #13; { ASCII Carriage return }
   LF    = #10; { ASCII Line feed       }

Begin

  DisplayMenu;

  Repeat

{--------------------------------------------------------------------------}
{ See if User has pressed a key - if so check for a command to execute     }
{--------------------------------------------------------------------------}
    If KeyPressed then
    begin
      ChIn := ReadKey;

      Case ChIn of
{ Turn on Module 1 in House A }
       '1'   : begin
                  WriteLn('Turning ON module 1 in House A.');
                  Exec('Control.exe', '/s(1,1,ON,1)');
                  If DosError <>0 then
                     WriteLn('DOS error # ', DosError);
                  WriteLn;
                  DisplayMenu;
                end;
{ Turn off Module 1 in House A }
       '2'    : begin
                  WriteLn('Turning OFF module 1 in House A.');
                  Exec('Control.exe', '/s(1,1,OFF,1)');
                  If DosError <>0 then
                     WriteLn('DOS error # ', DosError);
                  WriteLn;
                  DisplayMenu;
                end;
{ Turn on Module 2 in House A }
       '3'    : begin
                  WriteLn('Turning ON module 2 in House A.');
                  Exec('Control.exe', '/s(1,2,ON,1)');
                  If DosError <>0 then
                     WriteLn('DOS error # ', DosError);
                  WriteLn;
                  DisplayMenu;
                end;
{ Turn off Module 2 in House A }
       '4'    : begin
                  WriteLn('Turning OFF module 2 in House A.');
                  Exec('Control.exe', '/s(1,2,OFF,1)');
                  If DosError <>0 then
                     WriteLn('DOS error # ', DosError);
                  WriteLn;
                  DisplayMenu;
                end;
{ Switch to interactive mode }
       'I','i': begin
                  WriteLn('Interactive mode selected');
                  Write('Enter the House code (1 to 16) ');
                  ReadLn(HouseStr);
                  Write('Enter the Module number (1 to 16) ');
                  ReadLn(ModuleStr);
                  WriteLn('Enter the Function code as below ');
                  WriteLn(' AUF = All units off');
                  WriteLn(' AUN = All units on');
                  WriteLn(' ALN = All lamps on');
                  WriteLn(' ALF = All lamps off');
                  WriteLn(' AAN = All appliances on');
                  WriteLn(' AAF = All appliances off');
                  WriteLn(' ON  = Single module on');
                  WriteLn(' OFF = Single module off');
                  WriteLn(' DIM = Lamp module dim');
                  Write(' BRT = Lamp module bright ');
                  ReadLn(FunctionStr);
                  Write('Enter the Repeat number (1 to 10) ');
                  ReadLn(RepeatStr);
                  CommandLineStr := '/s('+HouseStr+','+ModuleStr+','+FunctionStr+','+RepeatStr+')';
                  WriteLn('CmdLine is ',CommandLineStr);
                  Exec('Control.exe', CommandLineStr);
                  If DosError <>0 then
                     WriteLn('DOS error # ', DosError);
                  WriteLn;
                  DisplayMenu;
                end;
       end; { case }

    end;

  until (ChIn = #27 ) or (ChIn = ^C); { Exit with Control C or ESC }

END; { TestPL513 }

{=====================================================================}
{                          Main Routine                               }
{=====================================================================}

BEGIN
   ClrScr;
   WriteLn('=========================================================================');
   WriteLn(' ',Title);
   WriteLn(' ',Version);
   WriteLn;
   WriteLn(' By Mike Genovy - Nov. 3, 2000');
   WriteLn('=========================================================================');
   WriteLn;
   WriteLn;
   TestPL513;
   WriteLn('Abort detected.......thats all folks !');
END.
